@@ -49,6 +49,14 @@ class TableName(Sql):
         return ".".join(map(c.quote, self.name))
 
 
+@dataclass
+class ColumnName(Sql):
+    name: str
+
+    def compile(self, c: Compiler):
+        return c.quote(self.name)
+
+
 @dataclass
 class Value(Sql):
     value: object  # Primitive
@@ -97,7 +105,7 @@ class Enum(Sql):
     order_by: SqlOrStr
 
     def compile(self, c: Compiler):
-        table =  ".".join(map(c.quote, self.table))
+        table = ".".join(map(c.quote, self.table))
         order = c.compile(self.order_by)
         return f"(SELECT *, (row_number() over (ORDER BY {order})) as idx FROM {table} ORDER BY {order}) tmp"
 
@@ -107,7 +115,7 @@ class Checksum(Sql):
     exprs: List[SqlOrStr]
 
     def compile(self, c: Compiler):
-        compiled_exprs = ", ".join(c.database.to_string(s) for s in map(c.compile, self.exprs))
+        compiled_exprs = ", ".join(map(c.compile, self.exprs))
         expr = f"concat({compiled_exprs})"
         md5 = c.database.md5_to_int(expr)
         return f"sum({md5})"
